#
# spec file for package exfat-utils
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Sidlovsky, Yaroslav <zawertun@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           exfat-utils
Version:        1.3.0
Release:        5.1
Summary:        Utilities for exFAT file system
License:        GPL-2.0-or-later
Group:          System/Filesystems
Url:            https://github.com/relan/exfat
Source0:        https://github.com/relan/exfat/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkg-config
Recommends:     fuse-exfat
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A set of utilities for creating, checking, dumping and labelling exFAT file
system.

%prep
%setup -q

%build
# force installation of manual pages
sed -i -e 's/no-installman//' configure.ac
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install
#UsrMerge
mkdir  %{buildroot}/sbin
ln -sf %{_sbindir}/{dumpexfat,exfatfsck,exfatlabel,fsck.exfat,mkexfatfs,mkfs.exfat} %{buildroot}/sbin
pushd %{buildroot}%{_mandir}/man8
#EndUsrMerge
ln -s exfatfsck.8.gz fsck.exfat.8.gz
ln -s mkexfatfs.8.gz mkfs.exfat.8.gz
popd

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README
#UsrMerge
/sbin/*
#EndUsrMerge
%{_sbindir}/dumpexfat
%{_sbindir}/exfatfsck
%{_sbindir}/exfatlabel
%{_sbindir}/fsck.exfat
%{_sbindir}/mkexfatfs
%{_sbindir}/mkfs.exfat
%{_mandir}/man8/dumpexfat.8%{ext_man}
%{_mandir}/man8/exfatfsck.8%{ext_man}
%{_mandir}/man8/exfatlabel.8%{ext_man}
%{_mandir}/man8/fsck.exfat.8%{ext_man}
%{_mandir}/man8/mkexfatfs.8%{ext_man}
%{_mandir}/man8/mkfs.exfat.8%{ext_man}

%changelog
* Thu Oct 18 2018 sean@suspend.net
- Update to 1.3.0
  * exfatfsck can now repair some errors
  * Added experimental Android support for exfa-utils
  * Cleaned up FUSE code preparing for FUSE 3 support
  * dirent ->d_type is now filled on readdir()
* Sat Aug 19 2017 asarai@suse.com
- Update to 1.2.7.
  * Fixed handling of two last clusters: operations with files that occupy these clusters could fail.
  * Fixed crash when started with stdin, stdout or stderr closed.
  [1.2.6]
  * Operations with directories (except initial listing) now make less read/write system calls.
  * Fixed handling of files with optional tail entries (0xe0-0xff): videoclip files created by Sony cameras were missing.
  * Write operations now correctly return ENOSPC (instead of EIO) when there is no free disk space left.
  * Fixed max file name length: it's 255 16-bit code units (not 256).
  [1.2.5]
  * Added an option for dumpexfat to show file fragments [Daniel Drake].
  * Fixed crash when directory starts with an invalid cluster.
  * Daylight saving time in now properly reflected in file timestamps.
* Sun Jun  5 2016 dap.darkness@gmail.com
- Update to 1.2.4:
  * Fixed wrong files names hashes.
  * Man pages are now installed by default.
  * Commas and backslashes in device names are now escaped.
* Sat Feb  6 2016 mpluskal@suse.com
- Provide symlinks to /sbin (see boo#965476)
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 1.2.3
  * Fixed clusters loss when file renaming replaces target.
* Fri Dec 11 2015 mpluskal@suse.com
- Update to 1.2.2
  * Improved reliability in case of a sudden unplug: FS will be in
  a clean state after closing all files and performing sync(1).
  * Fixed compilation on Debian GNU/kFreeBSD and GNU/Hurd
  platforms.
  * Updated mount.exfat-fuse man page.
* Sat Sep 26 2015 mpluskal@suse.com
- Update to 1.2.1
  * Fixed compatibility with Zalman VE-200: now newly created
    directories do not have archive bit set.
  * Fixed heap corruption: malformed FS can use invalid sector or
    cluster size.
  * Fixed hang on mount: malformed FS can have cyclic references
    in the clusters map.
* Tue Sep  1 2015 dsterba@suse.cz
- update to version 1.2.0
  * Switched from SCons to autotools.
  * Added musl libc support [Brendan Heading].
  * Worked around "FS is larger than device" error for memory cards
    formatted by Panasonic Lumix cameras.
  * Worked around "unknown entry type 0xe1" error for memory cards
    formatted by Sony cameras.
* Tue Feb 24 2015 virtuousfox@gmail.com
- Update to version 1.1.1:
  * Fixed mkfs crash on some sectors-per-cluster (-s option) values.
* Tue Aug 19 2014 lars@linux-schulserver.de
- specfile cleanup using spec-cleaner
- package Changelog and COPYING file
- recommend exfat-fuse package
- bzip the source
* Tue Jul  8 2014 zawertun@gmail.com
- Update to version 1.1.0:
  + Relicensed the project from GPLv3+ to GPLv2+.
  + OpenBSD support [Helg Bredow].
  + Improved I/O errors handling.
  + Implemented fsync() and fsyncdir().
  + Fixed crash on Mac OS X 10.5 caused by non-standard use of
    realpath(). Also fixed TrueCrypt disks unmounting.
  + Avoid extra erase on writes to the end of a file. This should
    improve linear write speed.
  + Allow arbitrary changing of lower 9 bits of mode. Allow
    owner/group changing to the same owner/group. This fixes rsync.
  + Fixed buffers overflows when handling lengthy file names.
  + Fixed "real size does not equal to size" error on volumes with
    pagefile.sys.
  + Fixed negative IUsed in "df -i" output.
* Tue Mar 26 2013 zawertun@gmail.com
- Update to version 1.0.1:
  + Fixed unexpected removal of a directory if it is moved into
    itself.
  + Fixed "Operation not permitted" error on reading an empty file.
* Tue Jan 22 2013 zawertun@gmail.com
- Added link from man page exfatfsck.8 to fsck.exfat.8 and from
  mkexfatfs.8 to mkfs.exfat.8
* Mon Jan 21 2013 zawertun@gmail.com
- Update to version 1.0.0:
  + Fixed crash when renaming a file within a single directory and
    a new name differs only in case.
  + Fixed clusters allocation: a cluster beyond valid clusters
    range
    could be allocated.
  + Fixed crash when a volume is unmounted while some files are
    open.
  + SConscript now respects AR and RANLIB environment variables.
  + Improved error handling.
  + Enabled big_writes. This improves write speed (larger block
    size means less switches between kernel- and user-space).
  + Do BLKROGET ioctl to make sure the device is not read-only:
    after "blockdev --setro" kernel still allows to open the device
    in read-write mode but fails writes.
* Sun Jan 13 2013 zawertun@gmail.com
- %%{optflags} passed as the value for CCFLAGS and CPPFLAGS
* Thu Sep 20 2012 zawertun@gmail.com
- Update to version 0.9.8:
  + The mkfs utility can now create huge file systems (up to several
    exabytes).
  + Fixed handling of characters beyond Basic Multilingual Plane.
  + Echo messages to syslog only if stderr is not connected to a
    terminal.
* Sat May  5 2012 zawertun@gmail.com
- Update to version 0.9.7:
  + Out-of-the-box FreeBSD support (via ublio library).
  + Fixed "missing EOD entry" error (could happen while reading
    directory that consists of several clusters).
  + Fixed interpretation of minutes field in files timestamps
    (minutes could be displayed incorrectly).
  + Fixed mtime seconds field initialization for newly created file
    (mtime could be 1 sec less than creation time).
  + SConscript now respects CC, CCFLAGS and LDFLAGS environment
    variables.
* Tue Jan 17 2012 zawertun@gmail.com
- Update to version 0.9.6:
  + Fixed write performance regression introduced in 0.9.4.
  + Mount in read-only mode if the device is write-protected.
  + Set ctime to mtime to ensure we don't break programs that rely on ctime
    (e.g. rsync considered that all files are outdated) [Eldad Zack].
  + Indicate that FS in not clean when it was not cleanly unmounted.
  + Utilities are now compatible with GNU/Hurd.
  + Fixed several memory leaks that could occur on error handling paths.
  + Improved handling of corrupted file systems.
* Mon Jun  6 2011 zawertun@gmail.com
- Update to version 0.9.5:
  + Fixed erasing of the root directory cluster when creating a new FS with mkexfatfs. This bug could cause mkexfatfs to produce invalid FS.
  + Utilities are not linked with libfuse anymore.
  + Ensure that the path being opened is either a device or a regular file.
